@@ -5,12 +5,22 @@
 """
 
 __author__ = "James Turk (jturk@sunlightfoundation.com)"
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 __copyright__ = "Copyright (c) 2009 Sunlight Labs"
 __license__ = "BSD"
 
-import urllib, urllib2
+import sys
 import warnings
+
+if sys.version_info[0] == 3:
+    from urllib.parse import urlencode
+    from urllib.request import urlopen
+    from urllib.error import HTTPError
+else:
+    from urllib import urlencode
+    from urllib2 import urlopen
+    from urllib2 import HTTPError
+
 try:
     import json
 except ImportError:
@@ -24,6 +34,10 @@ class SunlightApiObject(object):
     def __init__(self, d):
         self.__dict__ = d
 
+    def __repr__(self):
+        return '%s(%r)' % (self.__class__.__name__, self.__dict__)
+
+
 class Legislator(SunlightApiObject):
     def __str__(self):
         if self.nickname:
@@ -54,33 +68,6 @@ class District(SunlightApiObject):
     def __str__(self):
         return '%s-%s' % (self.state, self.number)
 
-class Lobbyist(SunlightApiObject):
-    def __str__(self):
-        return '%s %s' % (self.firstname, self.lastname)
-
-class Issue(SunlightApiObject):
-    def __str__(self):
-        return '%s (%s)' % (self.code, self.specific_issue)
-
-class Filing(SunlightApiObject):
-    def __init__(self, d):
-        self.__dict__ = d
-        self.lobbyists = [Lobbyist(l['lobbyist']) for l in self.lobbyists]
-        self.issues = [Issue(i['issue']) for i in self.issues]
-
-    def __str__(self):
-        return '%s - %s for %s' % (self.filing_id, self.registrant_name,
-                                   self.client_name)
-
-class FilingSearchResult(SunlightApiObject):
-    def __init__(self, d):
-        self.__dict__ = d['lobbyist']
-        self.score = d['score']
-
-    def __str__(self):
-        return '%s %s %s (%s)' % (self.score, self.firstname, self.lastname,
-                                  self.registrant_name)
-
 # namespaces #
 
 class sunlight(object):
@@ -93,11 +80,11 @@ class sunlight(object):
             raise SunlightApiError('Missing sunlight apikey')
 
         url = 'http://services.sunlightlabs.com/api/%s.json?apikey=%s&%s' % \
-              (func, sunlight.apikey, urllib.urlencode(params))
+              (func, sunlight.apikey, urlencode(params))
         try:
-            response = urllib2.urlopen(url).read()
+            response = urlopen(url).read().decode()
             return json.loads(response)['response']
-        except urllib2.HTTPError, e:
+        except HTTPError, e:
             raise SunlightApiError(e.read())
         except (ValueError, KeyError), e:
             raise SunlightApiError('Invalid Response')
@@ -126,6 +113,12 @@ class sunlight(object):
             results = sunlight._apicall('legislators.allForZip', {'zip':zipcode})
             return [Legislator(l['legislator']) for l in results['legislators']]
 
+        @staticmethod
+        def allForLatLong(latitude, longitude):
+            params = {'latitude':latitude, 'longitude':longitude}
+            results = sunlight._apicall('legislators.allForLatLong', params)
+            return [Legislator(l['legislator']) for l in results['legislators']]
+
     class committees(object):
         @staticmethod
         def get(committee_id):
@@ -160,59 +153,3 @@ class sunlight(object):
             params = {'latitude':latitude, 'longitude':longitude}
             result = sunlight._apicall('districts.getDistrictFromLatLong', params)
             return District(result['districts'][0]['district'])
-
-    class lobbyists(object):
-        @staticmethod
-        def getFiling(id):
-            warnings.warn('lobbyist methods deprecated as of September 2009', DeprecationWarning)
-            result = sunlight._apicall('lobbyists.getFiling', {'id':id})
-            return Filing(result['filing'])
-
-        @staticmethod
-        def getFilingList(**kwargs):
-            warnings.warn('lobbyist methods deprecated as of September 2009', DeprecationWarning)
-            results = sunlight._apicall('lobbyists.getFilingList', kwargs)
-            return [Filing(f['filing']) for f in results['filings']]
-
-        @staticmethod
-        def search(name, year=None, threshold=0.9):
-            warnings.warn('lobbyist methods deprecated as of September 2009', DeprecationWarning)
-            if year == None:
-                import time
-                year = time.strftime('%Y')
-            params = {'name':name, 'year':year, 'threshold': threshold}
-            results = sunlight._apicall('lobbyists.search', params)['results']
-            return [FilingSearchResult(f['result']) for f in results]
-
-    class wordlist(object):
-
-        @staticmethod
-        def _apicall(call, body=None):
-            warnings.warn('wordlist methods deprecated as of September 2009', DeprecationWarning)
-            base_url = 'http://services.sunlightlabs.com/api/wordlist'
-            url = '%s/%s/?apikey=%s' % (base_url, call, sunlight.apikey)
-            try:
-                if body:
-                    data = urllib.urlencode(body)
-                else:
-                    data = None
-                return urllib2.urlopen(url, data).read()
-            except urllib2.HTTPError, e:
-                raise SunlightApiError(e.read())
-
-        @staticmethod
-        def get(list_name):
-            warnings.warn('wordlist methods deprecated as of September 2009', DeprecationWarning)
-            words = sunlight.wordlist._apicall(list_name)
-            return words.split('~')
-
-        @staticmethod
-        def update(list_name, words):
-            warnings.warn('wordlist methods deprecated as of September 2009', DeprecationWarning)
-            sunlight.wordlist._apicall(list_name, {'words': '\n'.join(words)})
-
-        @staticmethod
-        def filter_stopwords(list_name, text):
-            warnings.warn('wordlist methods deprecated as of September 2009', DeprecationWarning)
-            call = '%s/filter_stopwords' % list_name
-            return sunlight.wordlist._apicall(call, {'text': text})
